@@ -173,6 +173,8 @@ _END
 			'<head><meta http-equiv="content-type" content="text/html; charset=EUC-JP"></head>hello',
 			'<head><meta http-equiv="content-type" content="text/html; charset=EUC_JP"></head>hello' =>
 			'<head><meta http-equiv="content-type" content="text/html; charset=EUC-JP"></head>hello',
+			"<meta http-equiv='Content-Type' content='text/html; charset=UTF-8' />" =>
+			"<meta http-equiv='Content-Type' content='text/html; charset=EUC-JP' />",
 		}.each_pair do |src, dst|
 			res = HTTPResponse.new( {:HTTPVersion => '1.1'} )
 			res.content_type = 'text/html'
